==> zqmb-1.0.1.tgz: package/lib/index.js <==
"use strict";

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _typeof2 = require("babel-runtime/helpers/typeof");

var _typeof3 = _interopRequireDefault(_typeof2);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _isomorphicFetch = require("isomorphic-fetch");

var _isomorphicFetch2 = _interopRequireDefault(_isomorphicFetch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Func_Zqmb = function Func_Zqmb() {
        var _this = this;

        (0, _classCallCheck3.default)(this, Func_Zqmb);

        this.sequence = function (msgSequence) {
            _this.msgSequence = msgSequence || null;
            return _this;
        };

        this.debug = function (msgDebug) {
            _this.msgDebug = msgDebug || Zqmb.debug;
            return _this;
        };

        this.timeout = function (msgTimeout) {
            if (!/^[0-9]*$/.test(msgTimeout)) {
                throw new Error("timeout 格式不正确!");
                return false;
            }
            _this.msgTimeout = msgTimeout || Zqmb.timeout;
            return _this;
        };

        this.bypass = function (msgBypass) {
            _this.msgBypass = msgBypass || Zqmb.bypass;
            return _this;
        };

        this.sysid = function (authSysid) {
            if (!/^[0-9]*$/.test(authSysid)) {
                throw new Error("authSysid 格式不正确!");
                return false;
            }
            _this.authSysid = authSysid || Zqmb.sysid;
            return _this;
        };

        this.token = function (authToken) {
            _this.authToken = authToken || Zqmb.token;
            return _this;
        };

        this.permit = function (authPermit) {
            _this.authPermit = authPermit || Zqmb.permit;
            return _this;
        };

        this.bizSequence = function (bSequence) {
            _this.bSequence = bSequence || null;
            return _this;
        };

        this.bizAccount = function (bAccount) {
            _this.bAccount = bAccount || Zqmb.account;
            return _this;
        };

        this.initHeaders = function () {
            if (_this.msgSequence) {
                _this.headers['msg.sequence'] = _this.msgSequence;
            }
            if (_this.msgDebug) {
                _this.headers['msg.debug'] = "Y";
            }
            if (_this.msgTimeout) {
                _this.headers['msg.timeout'] = _this.msgTimeout;
            }
            if (_this.msgBypass) {
                _this.headers['msg.bypass'] = _this.msgBypass;
            }
            if (_this.authSysid) {
                _this.headers["auth.sysid"] = _this.authSysid;
            }
            if (_this.authToken) {
                _this.headers["auth.token"] = _this.authToken;
            }
            if (_this.authPermit) {
                _this.headers["auth.permit"] = _this.authPermit;
            }
            if (_this.bSequence) {
                _this.headers["biz.sequence"] = _this.bSequence;
            }
            if (_this.bAccount) {
                _this.headers["biz.account"] = _this.bAccount;
            }
        };

        this.get = function (url) {
            for (var _len = arguments.length, inparams = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
                inparams[_key - 1] = arguments[_key];
            }

            if (!url) {
                throw new Error("get方法必须带一个url参数");
                return;
            }
            if (!_this.checkUrl(url)) {
                url = Zqmb.host + url;
            }
            _this.initHeaders();
            var m_params = inparams.map(function (param, index) {
                if (typeof param == "string") {
                    param = param.replace(/\"/g, "\\\"");
                    return "\"" + param + "\"";
                } else if ((typeof param === "undefined" ? "undefined" : (0, _typeof3.default)(param)) == "object") {
                    return "'" + (0, _stringify2.default)(param) + "'";
                }
                return param;
            });
            _this.params = m_params.join(",");
            var options = { method: 'POST', headers: _this.headers };
            if (_this.params) {
                options.body = _this.params;
            }
            return _this.fetch(url, options);
        };

        this.post = function (url) {
            for (var _len2 = arguments.length, inparams = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
                inparams[_key2 - 1] = arguments[_key2];
            }

            if (!url) {
                throw new Error("post方法必须带一个url参数");
                return;
            }
            if (!_this.checkUrl(url)) {
                url = Zqmb.host + url;
            }
            _this.initHeaders();
            var m_params = inparams.map(function (param, index) {
                if (typeof param == "string") {
                    param = param.replace(/\"/g, "\\\"");
                    return "\"" + param + "\"";
                } else if ((typeof param === "undefined" ? "undefined" : (0, _typeof3.default)(param)) == "object") {
                    return "'" + (0, _stringify2.default)(param) + "'";
                } else if (typeof param == "undefined") {
                    return "";
                }
                return param;
            });
            _this.params = m_params.join(",");
            var options = { method: 'POST', headers: _this.headers };
            if (_this.params) {
                options.body = _this.params;
            }
            return _this.fetch(url, options);
        };

        this.checkUrl = function (url) {
            var reg = /^(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&:/~\+#]*[\w\-\@?^=%&/~\+#])?/;
            return reg.test(url);
        };

        this.params = "";
        //MSG保留关键字
        this.msgSequence = null; //系统流水号（全调用链路唯一，比如调用链路C->S1->S2->S3，这4个调用的sys.sequence保持一致）
        this.msgDebug = Zqmb.debug; //是否开启debug调试
        this.msgTimeout = Zqmb.timeout; //超时时间设置,服务器默认为30000
        this.msgBypass = Zqmb.bypass; //N-不备份, Y-备份头 A-备份头+体 ，默认备份
        this.callback = "";
        this.authSysid = Zqmb.sysid; //系统编号
        this.authToken = Zqmb.token; //令牌
        this.authPermit = Zqmb.permit; //许可证
        /*BIZ保留关键字,设置到message头部，也可以直接设置*/
        this.bSequence = null; //业务流水号
        this.bAccount = Zqmb.account; //业务账号
        this.headers = { 'msg.callback': this.callback, 'auth.sysid': this.authSysid, 'auth.permit': this.authPermit };
        this.fetch = _isomorphicFetch2.default;
    }
//设置是否开启debug调试

//设置超时时间

    /*设置是否备份*/

    /*设置系统编号*/

    /*设置令牌*/

    /*设置许可证*/

    /*设置业务流水号*/

    /*设置业务账号*/


    /*验证url*/
; //import nodeFetch from 'node-fetch';


var Zqmb = {
    me: function me() {
        return new Func_Zqmb();
    },
    host: "",
    debug: false,
    timeout: null,
    bypass: "",
    sysid: "1002",
    token: "",
    permit: "exhqPb62I2BtMlaj5kkoJEWRFbvfxc",
    account: null,
    login: function login(authType, userid, passwd, authFactor, ext) {
        return Zqmb.me().post("/*/buadmin/authenticate", authType, userid, passwd, authFactor, ext).then(function (res) {
            return res.text();
        }).catch(function (err) {
            throw err;
        });
    }
    // commonjs
};module.exports = Zqmb;
// es6 default export compatibility
module.exports.default = module.exports;

==> zqmb-1.0.2.tgz: package/lib/index.js <==
"use strict";

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _typeof2 = require("babel-runtime/helpers/typeof");

var _typeof3 = _interopRequireDefault(_typeof2);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _isomorphicFetch = require("isomorphic-fetch");

var _isomorphicFetch2 = _interopRequireDefault(_isomorphicFetch);

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
}

var Func_Zqmb = function Func_Zqmb() {
        var _this = this;

        (0, _classCallCheck3.default)(this, Func_Zqmb);

        this.sequence = function (msgSequence) {
            _this.msgSequence = msgSequence || null;
            return _this;
        };

        this.debug = function (msgDebug) {
            _this.msgDebug = msgDebug || Zqmb.debug;
            return _this;
        };

        this.timeout = function (msgTimeout) {
            if (!/^[0-9]*$/.test(msgTimeout)) {
                throw new Error("timeout 格式不正确!");
                return false;
            }
            _this.msgTimeout = msgTimeout || Zqmb.timeout;
            return _this;
        };

        this.bypass = function (msgBypass) {
            _this.msgBypass = msgBypass || Zqmb.bypass;
            return _this;
        };

        this.sysid = function (authSysid) {
            if (!/^[0-9]*$/.test(authSysid)) {
                throw new Error("authSysid 格式不正确!");
                return false;
            }
            _this.authSysid = authSysid || Zqmb.sysid;
            return _this;
        };

        this.token = function (authToken) {
            _this.authToken = authToken || Zqmb.token;
            return _this;
        };

        this.permit = function (authPermit) {
            _this.authPermit = authPermit || Zqmb.permit;
            return _this;
        };

        this.bizSequence = function (bSequence) {
            _this.bSequence = bSequence || null;
            return _this;
        };

        this.bizAccount = function (bAccount) {
            _this.bAccount = bAccount || Zqmb.account;
            return _this;
        };

        this.initHeaders = function () {
            if (_this.msgSequence) {
                _this.headers['msg.sequence'] = _this.msgSequence;
            }
            if (_this.msgDebug) {
                _this.headers['msg.debug'] = "Y";
            }
            if (_this.msgTimeout) {
                _this.headers['msg.timeout'] = _this.msgTimeout;
            }
            if (_this.msgBypass) {
                _this.headers['msg.bypass'] = _this.msgBypass;
            }
            if (_this.authSysid) {
                _this.headers["auth.sysid"] = _this.authSysid;
            }
            if (_this.authToken) {
                _this.headers["auth.token"] = _this.authToken;
            }
            if (_this.authPermit) {
                _this.headers["auth.permit"] = _this.authPermit;
            }
            if (_this.bSequence) {
                _this.headers["biz.sequence"] = _this.bSequence;
            }
            if (_this.bAccount) {
                _this.headers["biz.account"] = _this.bAccount;
            }
        };

        this.get = function (url) {
            for (var _len = arguments.length, inparams = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
                inparams[_key - 1] = arguments[_key];
            }

            if (!url) {
                throw new Error("get方法必须带一个url参数");
                return;
            }
            if (!_this.checkUrl(url)) {
                url = Zqmb.host + url;
            }
            _this.initHeaders();
            var m_params = inparams.map(function (param, index) {
                if (typeof param == "string") {
                    param = param.replace(/\\/g, "\\\\");
                    param = param.replace(/\"/g, "\\\"");
                    return "\"" + param + "\"";
                } else if ((typeof param === "undefined" ? "undefined" : (0, _typeof3.default)(param)) == "object") {
                    return "'" + (0, _stringify2.default)(param) + "'";
                }
                return param;
            });
            _this.params = m_params.join(",");
            var options = { method: 'POST', headers: _this.headers };
            if (_this.params) {
                options.body = _this.params;
            }
            return _this.fetch(url, options);
        };

        this.post = function (url) {
            for (var _len2 = arguments.length, inparams = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
                inparams[_key2 - 1] = arguments[_key2];
            }

            if (!url) {
                throw new Error("post方法必须带一个url参数");
                return;
            }
            if (!_this.checkUrl(url)) {
                url = Zqmb.host + url;
            }
            _this.initHeaders();
            var m_params = inparams.map(function (param, index) {
                if (typeof param == "string") {
                    param = param.replace(/\\/g, "\\\\");
                    param = param.replace(/\"/g, "\\\"");
                    return "\"" + param + "\"";
                } else if ((typeof param === "undefined" ? "undefined" : (0, _typeof3.default)(param)) == "object") {
                    return "'" + (0, _stringify2.default)(param) + "'";
                } else if (typeof param == "undefined") {
                    return "";
                }
                return param;
            });
            _this.params = m_params.join(",");
            var options = { method: 'POST', headers: _this.headers };
            if (_this.params) {
                options.body = _this.params;
            }
            return _this.fetch(url, options);
        };

        this.checkUrl = function (url) {
            var reg = /^(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&:/~\+#]*[\w\-\@?^=%&/~\+#])?/;
            return reg.test(url);
        };

        this.params = "";
        //MSG保留关键字
        this.msgSequence = null; //系统流水号（全调用链路唯一，比如调用链路C->S1->S2->S3，这4个调用的sys.sequence保持一致）
        this.msgDebug = Zqmb.debug; //是否开启debug调试
        this.msgTimeout = Zqmb.timeout; //超时时间设置,服务器默认为30000
        this.msgBypass = Zqmb.bypass; //N-不备份, Y-备份头 A-备份头+体 ，默认备份
        this.callback = "";
        this.authSysid = Zqmb.sysid; //系统编号
        this.authToken = Zqmb.token; //令牌
        this.authPermit = Zqmb.permit; //许可证
        /*BIZ保留关键字,设置到message头部，也可以直接设置*/
        this.bSequence = null; //业务流水号
        this.bAccount = Zqmb.account; //业务账号
        this.headers = { 'msg.callback': this.callback, 'auth.sysid': this.authSysid, 'auth.permit': this.authPermit };
        this.fetch = _isomorphicFetch2.default;
    }
//设置是否开启debug调试

//设置超时时间

    /*设置是否备份*/

    /*设置系统编号*/

    /*设置令牌*/

    /*设置许可证*/

    /*设置业务流水号*/

    /*设置业务账号*/


    /*验证url*/
;

var Zqmb = {
    me: function me() {
        return new Func_Zqmb();
    },
    host: "",
    debug: false,
    timeout: null,
    bypass: "",
    sysid: "1002",
    token: "",
    permit: "exhqPb62I2BtMlaj5kkoJEWRFbvfxc",
    account: null,
    login: function login(authType, userid, passwd, authFactor, ext) {
        return Zqmb.me().post("/*/buadmin/authenticate", authType, userid, passwd, authFactor, ext).then(function (res) {
            return res.text();
        }).catch(function (err) {
            throw err;
        });
    }
    // commonjs
};
module.exports = Zqmb;
// es6 default export compatibility
module.exports.default = module.exports;
